.. DFAnalyzer documentation master file, created by
   sphinx-quickstart on Tue Jul  9 15:21:50 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to DFAnalyzer's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents

   overview
   getting-started
   configuration
   interactive-analysis
   tools



.. Indices and tables
.. ==================

.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`
